@@ -1,23 +1,20 @@
-import getpass
 import socket
-from ceph_deploy.lib.remoto import Connection
+from ceph_deploy.lib import remoto
 
 
-def get_connection(hostname, username, logger, threads=5, use_sudo=None):
+def get_connection(hostname, username, logger, threads=5, use_sudo=None, detect_sudo=True):
     """
     A very simple helper, meant to return a connection
     that will know about the need to use sudo.
     """
-    if use_sudo is None:
-        use_sudo = needs_sudo()
     if username:
         hostname = "%s@%s" % (username, hostname)
     try:
-        conn = Connection(
+        conn = remoto.Connection(
             hostname,
             logger=logger,
-            sudo=use_sudo,
             threads=threads,
+            detect_sudo=detect_sudo,
         )
 
         # Set a timeout value in seconds to disconnect and move on
@@ -42,11 +39,6 @@ def get_local_connection(logger, use_sudo=False):
         None,
         logger=logger,
         threads=1,
-        use_sudo=use_sudo
+        use_sudo=use_sudo,
+        detect_sudo=False
     )
-
-
-def needs_sudo():
-    if getpass.getuser() == 'root':
-        return False
-    return True
