@@ -14,13 +14,14 @@ def forgetkeys(args):
         'client.admin',
         'bootstrap-osd',
         'bootstrap-mds',
+        'bootstrap-rgw',
         ]:
         try:
             os.unlink('{cluster}.{what}.keyring'.format(
                     cluster=args.cluster,
                     what=f,
                     ))
-        except OSError, e:
+        except OSError as e:
             if e.errno == errno.ENOENT:
                 pass
             else:
