@@ -7,7 +7,7 @@ on the type of distribution/version we are dealing with.
 import logging
 from ceph_deploy import exc
 from ceph_deploy.util import versions
-from ceph_deploy.hosts import debian, centos, fedora, suse, remotes, rhel
+from ceph_deploy.hosts import debian, centos, fedora, suse, remotes, rhel, arch
 from ceph_deploy.connection import get_connection
 
 logger = logging.getLogger()
@@ -69,7 +69,8 @@ def get(hostname,
     module.is_el = module.normalized_name in ['redhat', 'centos', 'fedora', 'scientific', 'oracle', 'virtuozzo']
     module.is_rpm = module.normalized_name in ['redhat', 'centos',
                                                'fedora', 'scientific', 'suse', 'oracle', 'virtuozzo']
-    module.is_deb = not module.is_rpm
+    module.is_deb = module.normalized_name in ['debian', 'ubuntu']
+    module.is_pkgtarxz = module.normalized_name in ['arch']
     module.release = release
     module.codename = codename
     module.conn = conn
@@ -93,11 +94,12 @@ def _get_distro(distro, fallback=None, use_rhceph=False):
         'ubuntu': debian,
         'centos': centos,
         'scientific': centos,
-        'oracle' : centos,
+        'oracle': centos,
         'redhat': centos,
         'fedora': fedora,
         'suse': suse,
-        'virtuozzo' : centos
+        'virtuozzo': centos,
+        'arch': arch
         }
 
     if distro == 'redhat' and use_rhceph:
@@ -114,7 +116,7 @@ def _normalized_distro_name(distro):
         return 'scientific'
     elif distro.startswith('oracle'):
         return 'oracle'
-    elif distro.startswith(('suse', 'opensuse')):
+    elif distro.startswith(('suse', 'opensuse', 'sles')):
         return 'suse'
     elif distro.startswith('centos'):
         return 'centos'
@@ -122,6 +124,8 @@ def _normalized_distro_name(distro):
         return 'ubuntu'
     elif distro.startswith('virtuozzo'):
         return 'virtuozzo'
+    elif distro.startswith('arch'):
+        return 'arch'
     return distro
 
 
