@@ -1,6 +1,6 @@
-import mon  # noqa
-from install import install, mirror_install, repo_install  # noqa
-from uninstall import uninstall  # noqa
+from . import mon  # noqa
+from .install import install, mirror_install, repo_install  # noqa
+from .uninstall import uninstall  # noqa
 import logging
 
 from ceph_deploy.util import pkg_managers
@@ -24,7 +24,7 @@ def choose_init(module):
         '12' : 'systemd',               # SLE_12
         '13.1' : 'systemd',             # openSUSE_13.1
         }
-    return init_mapping.get(release, 'sysvinit')
+    return init_mapping.get(release, 'systemd')
 
 
 def get_packager(module):
