@@ -7,12 +7,11 @@ import time
 from ceph_deploy import conf, exc, admin
 from ceph_deploy.cliutil import priority
 from ceph_deploy.util.help_formatters import ToggleRawTextHelpFormatter
-from ceph_deploy.util import paths, net, files
+from ceph_deploy.util import paths, net, files, packages, system
 from ceph_deploy.lib import remoto
 from ceph_deploy.new import new_mon_keyring
 from ceph_deploy import hosts
 from ceph_deploy.misc import mon_hosts
-from ceph_deploy.connection import get_connection
 from ceph_deploy import gatherkeys
 
 
@@ -45,7 +44,7 @@ def mon_status_check(conn, logger, hostname, args):
         logger.error(line)
 
     try:
-        return json.loads(''.join(out))
+        return json.loads(b''.join(out).decode('utf-8'))
     except ValueError:
         return {}
 
@@ -176,7 +175,7 @@ def mon_add(args):
     mon_host = args.mon[0]
 
     try:
-        with file('{cluster}.mon.keyring'.format(cluster=args.cluster),
+        with open('{cluster}.mon.keyring'.format(cluster=args.cluster),
                   'rb') as f:
             monitor_keyring = f.read()
     except IOError:
@@ -208,7 +207,11 @@ def mon_add(args):
 
     try:
         LOG.debug('detecting platform for host %s ...', mon_host)
-        distro = hosts.get(mon_host, username=args.username)
+        distro = hosts.get(
+            mon_host,
+            username=args.username,
+            callbacks=[packages.ceph_is_installed]
+        )
         LOG.info('distro info: %s %s %s', distro.name, distro.release, distro.codename)
         rlogger = logging.getLogger(mon_host)
 
@@ -257,7 +260,11 @@ def mon_create(args):
         try:
             # TODO add_bootstrap_peer_hint
             LOG.debug('detecting platform for host %s ...', name)
-            distro = hosts.get(host, username=args.username)
+            distro = hosts.get(
+                host,
+                username=args.username,
+                callbacks=[packages.ceph_is_installed]
+            )
             LOG.info('distro info: %s %s %s', distro.name, distro.release, distro.codename)
             rlogger = logging.getLogger(name)
 
@@ -321,7 +328,7 @@ def destroy_mon(conn, cluster, hostname):
         )
 
         # stop
-        if conn.remote_module.path_exists(os.path.join(path, 'upstart')):
+        if conn.remote_module.path_exists(os.path.join(path, 'upstart')) or system.is_upstart(conn):
             status_args = [
                 'initctl',
                 'status',
@@ -337,6 +344,14 @@ def destroy_mon(conn, cluster, hostname):
                 'status',
                 'mon.{hostname}'.format(hostname=hostname),
             ]
+        elif system.is_systemd(conn):
+            status_args = [
+                'systemctl',
+                'stop',
+                'ceph-mon@{hostname}.service'.format(hostname=hostname),
+            ]
+        else:
+            raise RuntimeError('could not detect a supported init system, cannot continue')
 
         while retries:
             conn.logger.info('polling the daemon to verify it stopped')
@@ -373,7 +388,11 @@ def mon_destroy(args):
         try:
             LOG.debug('Removing mon from %s', name)
 
-            distro = hosts.get(host, username=args.username)
+            distro = hosts.get(
+                host,
+                username=args.username,
+                callbacks=[packages.ceph_is_installed]
+            )
             hostname = distro.conn.remote_module.shortname()
 
             destroy_mon(
@@ -408,9 +427,14 @@ def mon_create_initial(args):
         sleeps = [20, 20, 15, 10, 10, 5]
         tries = 5
         rlogger = logging.getLogger(host)
-        rconn = get_connection(host, username=args.username, logger=rlogger)
+        distro = hosts.get(
+            host,
+            username=args.username,
+            callbacks=[packages.ceph_is_installed]
+        )
+
         while tries:
-            status = mon_status_check(rconn, rlogger, host, args)
+            status = mon_status_check(distro.conn, rlogger, host, args)
             has_reached_quorum = status.get('state', '') in ['peon', 'leader']
             if not has_reached_quorum:
                 LOG.warning('%s monitor is not yet in quorum, tries left: %s' % (mon_name, tries))
@@ -422,7 +446,7 @@ def mon_create_initial(args):
                 mon_in_quorum.add(host)
                 LOG.info('%s monitor has reached quorum!', mon_name)
                 break
-        rconn.exit()
+        distro.conn.exit()
 
     if mon_in_quorum == mon_members:
         LOG.info('all initial monitors are running and have formed quorum')
@@ -456,6 +480,7 @@ def make(parser):
     parser.formatter_class = ToggleRawTextHelpFormatter
 
     mon_parser = parser.add_subparsers(dest='subcommand')
+    mon_parser.required = True
 
     mon_add = mon_parser.add_parser(
         'add',
@@ -564,8 +589,8 @@ def is_running(conn, args):
         conn,
         args
     )
-    result_string = ' '.join(stdout)
-    for run_check in [': running', ' start/running']:
+    result_string = b' '.join(stdout)
+    for run_check in [b': running', b' start/running']:
         if run_check in result_string:
             return True
     return False
