@@ -1,6 +1,7 @@
 import pytest
 
 from ceph_deploy.cli import get_parser
+from ceph_deploy.tests.util import assert_too_few_arguments
 
 
 class TestParserMDS(object):
@@ -20,7 +21,7 @@ class TestParserMDS(object):
         with pytest.raises(SystemExit):
             self.parser.parse_args('mds create'.split())
         out, err = capsys.readouterr()
-        assert "error: too few arguments" in err
+        assert_too_few_arguments(err)
 
     def test_mds_create_one_host(self):
         args = self.parser.parse_args('mds create host1'.split())
