@@ -1,188 +1,13 @@
 import os
-from urlparse import urlparse
+try:
+    from urllib.parse import urlparse
+except ImportError:
+    from urlparse import urlparse
 
 from ceph_deploy.lib import remoto
 from ceph_deploy.util import templates
 
 
-def apt(conn, packages, *a, **kw):
-    if isinstance(packages, str):
-        packages = [packages]
-    cmd = [
-        'env',
-        'DEBIAN_FRONTEND=noninteractive',
-        'apt-get',
-        'install',
-        '--assume-yes',
-    ]
-    cmd.extend(packages)
-    return remoto.process.run(
-        conn,
-        cmd,
-        *a,
-        **kw
-    )
-
-
-def apt_remove(conn, packages, *a, **kw):
-    if isinstance(packages, str):
-        packages = [packages]
-
-    purge = kw.pop('purge', False)
-    cmd = [
-        'apt-get',
-        '-q',
-        'remove',
-        '-f',
-        '-y',
-        '--force-yes',
-    ]
-    if purge:
-        cmd.append('--purge')
-    cmd.extend(packages)
-
-    return remoto.process.run(
-        conn,
-        cmd,
-        *a,
-        **kw
-    )
-
-
-def apt_update(conn):
-    cmd = [
-        'apt-get',
-        '-q',
-        'update',
-    ]
-    return remoto.process.run(
-        conn,
-        cmd,
-    )
-
-
-def yum(conn, packages, *a, **kw):
-    if isinstance(packages, str):
-        packages = [packages]
-
-    cmd = [
-        'yum',
-        '-y',
-        'install',
-    ]
-    cmd.extend(packages)
-    return remoto.process.run(
-        conn,
-        cmd,
-        *a,
-        **kw
-    )
-
-
-def yum_remove(conn, packages, *a, **kw):
-    cmd = [
-        'yum',
-        '-y',
-        '-q',
-        'remove',
-    ]
-    if isinstance(packages, str):
-        cmd.append(packages)
-    else:
-        cmd.extend(packages)
-    return remoto.process.run(
-        conn,
-        cmd,
-        *a,
-        **kw
-    )
-
-
-def yum_clean(conn, item=None):
-    item = item or 'all'
-    cmd = [
-        'yum',
-        'clean',
-        item,
-    ]
-
-    return remoto.process.run(
-        conn,
-        cmd,
-    )
-
-
-def rpm(conn, rpm_args=None, *a, **kw):
-    """
-    A minimal front end for ``rpm`. Extra flags can be passed in via
-    ``rpm_args`` as an iterable.
-    """
-    rpm_args = rpm_args or []
-    cmd = [
-        'rpm',
-        '-Uvh',
-    ]
-    cmd.extend(rpm_args)
-    return remoto.process.run(
-        conn,
-        cmd,
-        *a,
-        **kw
-    )
-
-
-def zypper(conn, packages, *a, **kw):
-    if isinstance(packages, str):
-        packages = [packages]
-
-    cmd = [
-        'zypper',
-        '--non-interactive',
-        'install',
-    ]
-
-    cmd.extend(packages)
-    return remoto.process.run(
-        conn,
-        cmd,
-        *a,
-        **kw
-    )
-
-
-def zypper_remove(conn, packages, *a, **kw):
-    cmd = [
-        'zypper',
-        '--non-interactive',
-        '--quiet',
-        'remove',
-        ]
-
-    if isinstance(packages, str):
-        cmd.append(packages)
-    else:
-        cmd.extend(packages)
-    return remoto.process.run(
-        conn,
-        cmd,
-        *a,
-        **kw
-    )
-
-
-def zypper_refresh(conn):
-    cmd = [
-        'zypper',
-        '--non-interactive',
-        'refresh',
-        ]
-
-    return remoto.process.run(
-        conn,
-        cmd
-    )
-
-
 class PackageManager(object):
     """
     Base class for all Package Managers
@@ -199,6 +24,13 @@ class PackageManager(object):
             **kw
         )
 
+    def _check(self, cmd, **kw):
+        return remoto.process.check(
+            self.remote_conn,
+            cmd,
+            **kw
+        )
+
     def install(self, packages, **kw):
         """Install packages on remote node"""
         raise NotImplementedError()
@@ -419,9 +251,9 @@ class Apt(PackageManager):
             self.add_repo_gpg_key(gpg_url)
 
         safe_filename = '%s.list' % name.replace(' ', '-')
-        mode = 0644
+        mode = 0o644
         if urlparse(url).password:
-            mode = 0600
+            mode = 0o600
             self.remote_conn.logger.info(
                 "Creating repo file with mode 0600 due to presence of password"
             )
@@ -475,7 +307,46 @@ class Zypper(PackageManager):
             packages = [packages]
 
         extra_flags = kw.pop('extra_remove_flags', None)
-        cmd = self.executable + ['remove']
+        cmd = self.executable + ['--ignore-unknown', 'remove']
+        if extra_flags:
+            if isinstance(extra_flags, str):
+                extra_flags = [extra_flags]
+            cmd.extend(extra_flags)
+        cmd.extend(packages)
+        stdout, stderr, exitrc = self._check(
+            cmd,
+            **kw
+        )
+        # exitrc is 104 when package(s) not installed.
+        if not exitrc in [0, 104]:
+            raise RuntimeError("Failed to execute command: %s" % " ".join(cmd))
+        return
+
+    def clean(self):
+        cmd = self.executable + ['refresh']
+        return self._run(cmd)
+
+
+class Pacman(PackageManager):
+    """
+    Pacman package management
+    """
+
+    executable = [
+        'pacman',
+        '--noconfirm',
+    ]
+    name = 'pacman'
+
+    def install(self, packages, **kw):
+        if isinstance(packages, str):
+            packages = [packages]
+
+        extra_flags = kw.pop('extra_install_flags', None)
+        cmd = self.executable + [
+            '-Sy',
+        ]
+
         if extra_flags:
             if isinstance(extra_flags, str):
                 extra_flags = [extra_flags]
@@ -483,6 +354,26 @@ class Zypper(PackageManager):
         cmd.extend(packages)
         return self._run(cmd)
 
-    def clean(self):
-        cmd = self.executable + ['refresh']
+    def remove(self, packages, **kw):
+        if isinstance(packages, str):
+            packages = [packages]
+
+        extra_flags = kw.pop('extra_remove_flags', None)
+        cmd = self.executable + [
+            '-R'
+        ]
+        if extra_flags:
+            if isinstance(extra_flags, str):
+                extra_flags = [extra_flags]
+            cmd.extend(extra_flags)
+
+        cmd.extend(packages)
         return self._run(cmd)
+
+    def clean(self):
+        cmd = self.executable + ['-Syy']
+        return self._run(cmd)
+
+    def add_repo_gpg_key(self, url):
+        cmd = ['pacman-key', '-a', url]
+        self._run(cmd)
